trident.models package
======================

Submodules
----------

trident.models.pytorch\_arcfacenet module
-----------------------------------------

.. automodule:: trident.models.pytorch_arcfacenet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_deeplab module
--------------------------------------

.. automodule:: trident.models.pytorch_deeplab
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_densenet module
---------------------------------------

.. automodule:: trident.models.pytorch_densenet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_efficientnet module
-------------------------------------------

.. automodule:: trident.models.pytorch_efficientnet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_gan module
----------------------------------

.. automodule:: trident.models.pytorch_gan
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_mobilenet module
----------------------------------------

.. automodule:: trident.models.pytorch_mobilenet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_mtcnn module
------------------------------------

.. automodule:: trident.models.pytorch_mtcnn
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_resnet module
-------------------------------------

.. automodule:: trident.models.pytorch_resnet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_rfbnet module
-------------------------------------

.. automodule:: trident.models.pytorch_rfbnet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_ssd module
----------------------------------

.. automodule:: trident.models.pytorch_ssd
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_vgg module
----------------------------------

.. automodule:: trident.models.pytorch_vgg
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.pytorch\_yolo module
-----------------------------------

.. automodule:: trident.models.pytorch_yolo
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.tensorflow\_efficientnet module
----------------------------------------------

.. automodule:: trident.models.tensorflow_efficientnet
   :members:
   :undoc-members:
   :show-inheritance:

trident.models.tensorflow\_resnet module
----------------------------------------

.. automodule:: trident.models.tensorflow_resnet
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.models
   :members:
   :undoc-members:
   :show-inheritance:
